@@ -779,9 +779,15 @@ class Tableau(Dialect):
     def _if_sql(self, expression):
         return f"IF {self.sql(expression, 'this')} THEN {self.sql(expression, 'true')} ELSE {self.sql(expression, 'false')} END"
 
-    transforms = {
-        exp.If: _if_sql,
-    }
+    def _coalesce_sql(self, expression):
+        return f"IFNULL({self.sql(expression, 'this')}, {self.expressions(expression)})"
+
+    def _count_sql(self, expression):
+        if expression.args.get("distinct"):
+            return f"COUNTD{self.sql(expression, 'this')}"
+        return f"COUNT({self.sql(expression, 'this')})"
+
+    transforms = {exp.If: _if_sql, exp.Coalesce: _coalesce_sql, exp.Count: _count_sql}
 
 
 class Trino(Presto):
