@@ -347,6 +347,11 @@ class Generator:
         exists = "NOT EXISTS" if expression.args.get("not") else "EXISTS"
         return f"{exists} {self.sql(expression, 'this')}"
 
+    def filter_sql(self, expression):
+        this = self.sql(expression, "this")
+        where = self.sql(expression, "expression")[1:]  # where has a leading space
+        return f"{this} FILTER({where})"
+
     def hint_sql(self, expression):
         if self.sql(expression, "this"):
             self.unsupported("Hints are not supported")
@@ -518,6 +523,7 @@ class Generator:
             self.sql(expression, "where"),
             self.sql(expression, "group"),
             self.sql(expression, "having"),
+            self.sql(expression, "qualify"),
             self.sql(expression, "order"),
             self.sql(expression, "limit"),
             self.sql(expression, "offset"),
@@ -542,6 +548,10 @@ class Generator:
             return f"{self.wrap(expression)}{alias}"
         return f"({self.sql(expression, 'this')}){alias}"
 
+    def qualify_sql(self, expression):
+        this = self.indent_newlines(self.sql(expression, "this"))
+        return f"{self.seg('QUALIFY')}{self.sep()}{this}"
+
     def union_sql(self, expression):
         return self.set_operation(
             expression, f"UNION{'' if expression.args.get('distinct') else ' ALL'}"
@@ -585,6 +595,11 @@ class Generator:
         )
         return f"{kind} BETWEEN {start} AND {end}"
 
+    def withingroup_sql(self, expression):
+        this = self.sql(expression, "this")
+        expression = self.sql(expression, "expression")[1:]  # order has a leading space
+        return f"{this} WITHIN GROUP ({expression})"
+
     def between_sql(self, expression):
         this = self.sql(expression, "this")
         low = self.sql(expression, "low")
